summaryrefslogtreecommitdiff
path: root/vcl
diff options
context:
space:
mode:
authorChris Sherlock <chris.sherlock79@gmail.com>2022-06-24 18:16:07 +1000
committerTomaž Vajngerl <quikee@gmail.com>2022-07-19 19:52:11 +0200
commit44422b97e9d6398919445363b81b4cd1ab184ce3 (patch)
treecf379b94064494323a9e4c9fc1955a47e6e44050 /vcl
parent93b07a377b93875b28464546f1292e4aa5f9e17d (diff)
vcl: AInfo -> AnimationData
Change-Id: I4a4f8e2e346010edd1fde004eb9f14b67fc8487a Reviewed-on: https://gerrit.libreoffice.org/c/core/+/76407 Tested-by: Jenkins Reviewed-by: Tomaž Vajngerl <quikee@gmail.com>
Diffstat (limited to 'vcl')
-rw-r--r--vcl/inc/animate/AnimationRenderer.hxx6
-rw-r--r--vcl/source/animate/Animation.cxx23
-rw-r--r--vcl/source/animate/AnimationRenderer.cxx18
3 files changed, 24 insertions, 23 deletions
diff --git a/vcl/inc/animate/AnimationRenderer.hxx b/vcl/inc/animate/AnimationRenderer.hxx
index 18128558a44e..6b86d07bb2de 100644
--- a/vcl/inc/animate/AnimationRenderer.hxx
+++ b/vcl/inc/animate/AnimationRenderer.hxx
@@ -28,7 +28,7 @@ class OutputDevice;
class VirtualDevice;
struct AnimationBitmap;
-struct AInfo
+struct AnimationData
{
Point aStartOrg;
Size aStartSize;
@@ -37,7 +37,7 @@ struct AInfo
tools::Long nRendererId;
bool bPause;
- AInfo();
+ AnimationData();
};
@@ -78,7 +78,7 @@ public:
void drawToIndex( sal_uLong nIndex );
void draw( sal_uLong nIndex, VirtualDevice* pVDev=nullptr );
void repaint();
- AInfo* createAInfo() const;
+ AnimationData* createAnimationData() const;
void getPosSize( const AnimationBitmap& rAnm, Point& rPosPix, Size& rSizePix );
diff --git a/vcl/source/animate/AnimationRenderer.cxx b/vcl/source/animate/AnimationRenderer.cxx
index 59843e19c893..51aaa590d24b 100644
--- a/vcl/source/animate/AnimationRenderer.cxx
+++ b/vcl/source/animate/AnimationRenderer.cxx
@@ -307,18 +307,18 @@ void AnimationRenderer::repaint()
mbIsPaused = bOldPause;
}
-AInfo* AnimationRenderer::createAInfo() const
+AnimationData* AnimationRenderer::createAnimationData() const
{
- AInfo* pAInfo = new AInfo;
+ AnimationData* pDataItem = new AnimationData;
- pAInfo->aStartOrg = maPt;
- pAInfo->aStartSize = maSz;
- pAInfo->pOutDev = mpRenderContext;
- pAInfo->pRendererData = const_cast<AnimationRenderer *>(this);
- pAInfo->nRendererId = mnRendererId;
- pAInfo->bPause = mbIsPaused;
+ pDataItem->aStartOrg = maPt;
+ pDataItem->aStartSize = maSz;
+ pDataItem->pOutDev = mpRenderContext;
+ pDataItem->pRendererData = const_cast<AnimationRenderer *>(this);
+ pDataItem->nRendererId = mnRendererId;
+ pDataItem->bPause = mbIsPaused;
- return pAInfo;
+ return pDataItem;
}
/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/vcl/source/animate/Animation.cxx b/vcl/source/animate/Animation.cxx
index b0270c194c95..f7d6a4f27a93 100644
--- a/vcl/source/animate/Animation.cxx
+++ b/vcl/source/animate/Animation.cxx
@@ -290,30 +290,31 @@ IMPL_LINK_NOARG(Animation, ImplTimeoutHdl, Timer*, void)
if (maNotifyLink.IsSet())
{
- std::vector<std::unique_ptr<AInfo>> aAInfoList;
- // create AInfo-List
+ std::vector<std::unique_ptr<AnimationData>> aDataItems;
+ // create AnimationData-List
for (auto const& i : maRenderers)
- aAInfoList.emplace_back(i->createAInfo());
+ aDataItems.emplace_back(i->createAnimationData());
maNotifyLink.Call(this);
- // set view state from AInfo structure
- for (auto& pAInfo : aAInfoList)
+ // set view state from AnimationData structure
+ for (auto& pDataItem : aDataItems)
{
AnimationRenderer* pRenderer = nullptr;
- if (!pAInfo->pRendererData)
+ if (!pDataItem->pRendererData)
{
- pRenderer = new AnimationRenderer(this, pAInfo->pOutDev, pAInfo->aStartOrg,
- pAInfo->aStartSize, pAInfo->nRendererId);
+ pRenderer
+ = new AnimationRenderer(this, pDataItem->pOutDev, pDataItem->aStartOrg,
+ pDataItem->aStartSize, pDataItem->nRendererId);
maRenderers.push_back(std::unique_ptr<AnimationRenderer>(pRenderer));
}
else
{
- pRenderer = static_cast<AnimationRenderer*>(pAInfo->pRendererData);
+ pRenderer = static_cast<AnimationRenderer*>(pDataItem->pRendererData);
}
- pRenderer->pause(pAInfo->bPause);
+ pRenderer->pause(pDataItem->bPause);
pRenderer->setMarked(true);
}
@@ -680,7 +681,7 @@ SvStream& ReadAnimation(SvStream& rIStm, Animation& rAnimation)
return rIStm;
}
-AInfo::AInfo()
+AnimationData::AnimationData()
: pOutDev(nullptr)
, pRendererData(nullptr)
, nRendererId(0)